@@ -6,13 +6,7 @@
 
 #pragma once
 
-/**
- * SECTION:fwupd-version
- * @short_description: Obtains the version for the installed fwupd
- *
- * These compile time macros allow the user to enable parts of client code
- * depending on the version of libfwupd installed.
- */
+#include <glib.h>
 
 #if !defined (__FWUPD_H_INSIDE__) && !defined (FWUPD_COMPILATION)
 #error "Only <fwupd.h> can be included directly."
@@ -33,7 +27,7 @@
  * The compile-time minor version
  */
 #ifndef FWUPD_MINOR_VERSION
-#define FWUPD_MINOR_VERSION				(5)
+#define FWUPD_MINOR_VERSION				(6)
 #endif
 
 /**
@@ -42,7 +36,7 @@
  * The compile-time micro version
  */
 #ifndef FWUPD_MICRO_VERSION
-#define FWUPD_MICRO_VERSION				(8)
+#define FWUPD_MICRO_VERSION				(1)
 #endif
 
 /**
@@ -53,9 +47,14 @@
  *
  * Check whether a fwupd version equal to or greater than
  * major.minor.micro.
+ *
+ * These compile time macros allow the user to enable parts of client code
+ * depending on the version of libfwupd installed.
  */
 #define FWUPD_CHECK_VERSION(major,minor,micro)    \
     (FWUPD_MAJOR_VERSION > (major) || \
      (FWUPD_MAJOR_VERSION == (major) && FWUPD_MINOR_VERSION > (minor)) || \
      (FWUPD_MAJOR_VERSION == (major) && FWUPD_MINOR_VERSION == (minor) && \
       FWUPD_MICRO_VERSION >= (micro)))
+
+const gchar	*fwupd_version_string			(void);
