@@ -20,6 +20,7 @@ G_DECLARE_DERIVABLE_TYPE (FuDevice, fu_device, FU, DEVICE, FwupdDevice)
 struct _FuDeviceClass
 {
 	FwupdDeviceClass	 parent_class;
+#ifndef __GI_SCANNER__
 	void			 (*to_string)		(FuDevice	*self,
 							 guint		 indent,
 							 GString	*str);
@@ -100,6 +101,7 @@ struct _FuDeviceClass
 							 FuSecurityAttrs *attrs);
 	/*< private >*/
 	gpointer	padding[10];
+#endif
 };
 
 /**
@@ -134,7 +136,17 @@ typedef enum {
  */
 #define FU_DEVICE_REMOVE_DELAY_USER_REPLUG		40000
 
-typedef gboolean (*FuDeviceRetryFunc)			(FuDevice	*device,
+/**
+ * FuDeviceRetryFunc:
+ * @self: a #FuDevice
+ * @user_data: user data
+ * @error: (nullable): optional return location for an error
+ *
+ * The device retry iteration callback.
+ *
+ * Returns: %TRUE on success
+ */
+typedef gboolean (*FuDeviceRetryFunc)			(FuDevice	*self,
 							 gpointer	 user_data,
 							 GError		**error)
 							 G_GNUC_WARN_UNUSED_RESULT;
@@ -212,6 +224,7 @@ FuDevice	*fu_device_new				(void);
  * @FU_DEVICE_INTERNAL_FLAG_RETRY_OPEN:			Retry the device open up to 5 times if it fails
  * @FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID:		Match GUIDs on device replug where the physical and logical IDs will be different
  * @FU_DEVICE_INTERNAL_FLAG_INHERIT_ACTIVATION:		Inherit activation status from the history database on startup
+ * @FU_DEVICE_INTERNAL_FLAG_IS_OPEN:			The device opened successfully and ready to use
  *
  * The device internal flags.
  **/
@@ -227,6 +240,7 @@ typedef enum {
 	FU_DEVICE_INTERNAL_FLAG_RETRY_OPEN		= (1llu << 7),	/* Since: 1.5.5 */
 	FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID	= (1llu << 8),	/* Since: 1.5.8 */
 	FU_DEVICE_INTERNAL_FLAG_INHERIT_ACTIVATION	= (1llu << 9),  /* Since: 1.5.9 */
+	FU_DEVICE_INTERNAL_FLAG_IS_OPEN			= (1llu << 10),	/* Since: 1.6.1 */
 	/*< private >*/
 	FU_DEVICE_INTERNAL_FLAG_UNKNOWN			= G_MAXUINT64,
 } FuDeviceInternalFlags;
